==> openshift-model-monitoring-5.11.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/QueueConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class QueueConfigFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.QueueConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.QueueConfigFluent<A>{
  public QueueConfigFluentImpl() {
  }
  public QueueConfigFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.QueueConfig instance) {
    this.withBatchSendDeadline(instance.getBatchSendDeadline()); 
    this.withCapacity(instance.getCapacity()); 
    this.withMaxBackoff(instance.getMaxBackoff()); 
    this.withMaxRetries(instance.getMaxRetries()); 
    this.withMaxSamplesPerSend(instance.getMaxSamplesPerSend()); 
    this.withMaxShards(instance.getMaxShards()); 
    this.withMinBackoff(instance.getMinBackoff()); 
    this.withMinShards(instance.getMinShards()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String batchSendDeadline;
  private java.lang.Integer capacity;
  private java.lang.String maxBackoff;
  private java.lang.Integer maxRetries;
  private java.lang.Integer maxSamplesPerSend;
  private java.lang.Integer maxShards;
  private java.lang.String minBackoff;
  private java.lang.Integer minShards;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getBatchSendDeadline() {
    return this.batchSendDeadline;
  }
  public A withBatchSendDeadline(java.lang.String batchSendDeadline) {
    this.batchSendDeadline=batchSendDeadline; return (A) this;
  }
  public java.lang.Boolean hasBatchSendDeadline() {
    return this.batchSendDeadline != null;
  }
  
  /**
   * Method is deprecated. use withBatchSendDeadline instead.
   */
  @java.lang.Deprecated
  public A withNewBatchSendDeadline(java.lang.String arg0) {
    return (A)withBatchSendDeadline(new String(arg0));
  }
  public java.lang.Integer getCapacity() {
    return this.capacity;
  }
  public A withCapacity(java.lang.Integer capacity) {
    this.capacity=capacity; return (A) this;
  }
  public java.lang.Boolean hasCapacity() {
    return this.capacity != null;
  }
  public java.lang.String getMaxBackoff() {
    return this.maxBackoff;
  }
  public A withMaxBackoff(java.lang.String maxBackoff) {
    this.maxBackoff=maxBackoff; return (A) this;
  }
  public java.lang.Boolean hasMaxBackoff() {
    return this.maxBackoff != null;
  }
  
  /**
   * Method is deprecated. use withMaxBackoff instead.
   */
  @java.lang.Deprecated
  public A withNewMaxBackoff(java.lang.String arg0) {
    return (A)withMaxBackoff(new String(arg0));
  }
  public java.lang.Integer getMaxRetries() {
    return this.maxRetries;
  }
  public A withMaxRetries(java.lang.Integer maxRetries) {
    this.maxRetries=maxRetries; return (A) this;
  }
  public java.lang.Boolean hasMaxRetries() {
    return this.maxRetries != null;
  }
  public java.lang.Integer getMaxSamplesPerSend() {
    return this.maxSamplesPerSend;
  }
  public A withMaxSamplesPerSend(java.lang.Integer maxSamplesPerSend) {
    this.maxSamplesPerSend=maxSamplesPerSend; return (A) this;
  }
  public java.lang.Boolean hasMaxSamplesPerSend() {
    return this.maxSamplesPerSend != null;
  }
  public java.lang.Integer getMaxShards() {
    return this.maxShards;
  }
  public A withMaxShards(java.lang.Integer maxShards) {
    this.maxShards=maxShards; return (A) this;
  }
  public java.lang.Boolean hasMaxShards() {
    return this.maxShards != null;
  }
  public java.lang.String getMinBackoff() {
    return this.minBackoff;
  }
  public A withMinBackoff(java.lang.String minBackoff) {
    this.minBackoff=minBackoff; return (A) this;
  }
  public java.lang.Boolean hasMinBackoff() {
    return this.minBackoff != null;
  }
  
  /**
   * Method is deprecated. use withMinBackoff instead.
   */
  @java.lang.Deprecated
  public A withNewMinBackoff(java.lang.String arg0) {
    return (A)withMinBackoff(new String(arg0));
  }
  public java.lang.Integer getMinShards() {
    return this.minShards;
  }
  public A withMinShards(java.lang.Integer minShards) {
    this.minShards=minShards; return (A) this;
  }
  public java.lang.Boolean hasMinShards() {
    return this.minShards != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    QueueConfigFluentImpl that = (QueueConfigFluentImpl) o;
    if (batchSendDeadline != null ? !batchSendDeadline.equals(that.batchSendDeadline) :that.batchSendDeadline != null) return false;
    if (capacity != null ? !capacity.equals(that.capacity) :that.capacity != null) return false;
    if (maxBackoff != null ? !maxBackoff.equals(that.maxBackoff) :that.maxBackoff != null) return false;
    if (maxRetries != null ? !maxRetries.equals(that.maxRetries) :that.maxRetries != null) return false;
    if (maxSamplesPerSend != null ? !maxSamplesPerSend.equals(that.maxSamplesPerSend) :that.maxSamplesPerSend != null) return false;
    if (maxShards != null ? !maxShards.equals(that.maxShards) :that.maxShards != null) return false;
    if (minBackoff != null ? !minBackoff.equals(that.minBackoff) :that.minBackoff != null) return false;
    if (minShards != null ? !minShards.equals(that.minShards) :that.minShards != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(batchSendDeadline,  capacity,  maxBackoff,  maxRetries,  maxSamplesPerSend,  maxShards,  minBackoff,  minShards,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/QueueConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class QueueConfigFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.QueueConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.QueueConfigFluent<A>{
  public QueueConfigFluentImpl() {
  }
  public QueueConfigFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.QueueConfig instance) {
    this.withBatchSendDeadline(instance.getBatchSendDeadline()); 
    this.withCapacity(instance.getCapacity()); 
    this.withMaxBackoff(instance.getMaxBackoff()); 
    this.withMaxRetries(instance.getMaxRetries()); 
    this.withMaxSamplesPerSend(instance.getMaxSamplesPerSend()); 
    this.withMaxShards(instance.getMaxShards()); 
    this.withMinBackoff(instance.getMinBackoff()); 
    this.withMinShards(instance.getMinShards()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String batchSendDeadline;
  private java.lang.Integer capacity;
  private java.lang.String maxBackoff;
  private java.lang.Integer maxRetries;
  private java.lang.Integer maxSamplesPerSend;
  private java.lang.Integer maxShards;
  private java.lang.String minBackoff;
  private java.lang.Integer minShards;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getBatchSendDeadline() {
    return this.batchSendDeadline;
  }
  public A withBatchSendDeadline(java.lang.String batchSendDeadline) {
    this.batchSendDeadline=batchSendDeadline; return (A) this;
  }
  public java.lang.Boolean hasBatchSendDeadline() {
    return this.batchSendDeadline != null;
  }
  
  /**
   * Method is deprecated. use withBatchSendDeadline instead.
   */
  @java.lang.Deprecated
  public A withNewBatchSendDeadline(java.lang.String arg0) {
    return (A)withBatchSendDeadline(new String(arg0));
  }
  public java.lang.Integer getCapacity() {
    return this.capacity;
  }
  public A withCapacity(java.lang.Integer capacity) {
    this.capacity=capacity; return (A) this;
  }
  public java.lang.Boolean hasCapacity() {
    return this.capacity != null;
  }
  public java.lang.String getMaxBackoff() {
    return this.maxBackoff;
  }
  public A withMaxBackoff(java.lang.String maxBackoff) {
    this.maxBackoff=maxBackoff; return (A) this;
  }
  public java.lang.Boolean hasMaxBackoff() {
    return this.maxBackoff != null;
  }
  
  /**
   * Method is deprecated. use withMaxBackoff instead.
   */
  @java.lang.Deprecated
  public A withNewMaxBackoff(java.lang.String arg0) {
    return (A)withMaxBackoff(new String(arg0));
  }
  public java.lang.Integer getMaxRetries() {
    return this.maxRetries;
  }
  public A withMaxRetries(java.lang.Integer maxRetries) {
    this.maxRetries=maxRetries; return (A) this;
  }
  public java.lang.Boolean hasMaxRetries() {
    return this.maxRetries != null;
  }
  public java.lang.Integer getMaxSamplesPerSend() {
    return this.maxSamplesPerSend;
  }
  public A withMaxSamplesPerSend(java.lang.Integer maxSamplesPerSend) {
    this.maxSamplesPerSend=maxSamplesPerSend; return (A) this;
  }
  public java.lang.Boolean hasMaxSamplesPerSend() {
    return this.maxSamplesPerSend != null;
  }
  public java.lang.Integer getMaxShards() {
    return this.maxShards;
  }
  public A withMaxShards(java.lang.Integer maxShards) {
    this.maxShards=maxShards; return (A) this;
  }
  public java.lang.Boolean hasMaxShards() {
    return this.maxShards != null;
  }
  public java.lang.String getMinBackoff() {
    return this.minBackoff;
  }
  public A withMinBackoff(java.lang.String minBackoff) {
    this.minBackoff=minBackoff; return (A) this;
  }
  public java.lang.Boolean hasMinBackoff() {
    return this.minBackoff != null;
  }
  
  /**
   * Method is deprecated. use withMinBackoff instead.
   */
  @java.lang.Deprecated
  public A withNewMinBackoff(java.lang.String arg0) {
    return (A)withMinBackoff(new String(arg0));
  }
  public java.lang.Integer getMinShards() {
    return this.minShards;
  }
  public A withMinShards(java.lang.Integer minShards) {
    this.minShards=minShards; return (A) this;
  }
  public java.lang.Boolean hasMinShards() {
    return this.minShards != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    QueueConfigFluentImpl that = (QueueConfigFluentImpl) o;
    if (batchSendDeadline != null ? !batchSendDeadline.equals(that.batchSendDeadline) :that.batchSendDeadline != null) return false;
    if (capacity != null ? !capacity.equals(that.capacity) :that.capacity != null) return false;
    if (maxBackoff != null ? !maxBackoff.equals(that.maxBackoff) :that.maxBackoff != null) return false;
    if (maxRetries != null ? !maxRetries.equals(that.maxRetries) :that.maxRetries != null) return false;
    if (maxSamplesPerSend != null ? !maxSamplesPerSend.equals(that.maxSamplesPerSend) :that.maxSamplesPerSend != null) return false;
    if (maxShards != null ? !maxShards.equals(that.maxShards) :that.maxShards != null) return false;
    if (minBackoff != null ? !minBackoff.equals(that.minBackoff) :that.minBackoff != null) return false;
    if (minShards != null ? !minShards.equals(that.minShards) :that.minShards != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(batchSendDeadline,  capacity,  maxBackoff,  maxRetries,  maxSamplesPerSend,  maxShards,  minBackoff,  minShards,  additionalProperties,  super.hashCode());
  }
  
}
